@@ -581,7 +581,7 @@ class ObjectResource(ContentNegotiatedMethodView):
                     ObjectVersionTag.create(obj, key, value)
 
         db.session.commit()
-        file_uploaded.send(current_app._get_current_object(), obj=obj)
+        file_uploaded.send(obj)
         return self.make_response(
             data=obj,
             context={
@@ -627,7 +627,7 @@ class ObjectResource(ContentNegotiatedMethodView):
             if obj.file_id:
                 remove_file_data.delay(str(obj.file_id))
         db.session.commit()
-        file_deleted.send(current_app._get_current_object(), obj=obj)
+        file_deleted.send(obj)
         return self.make_response('', 204)
 
     @staticmethod
@@ -653,7 +653,7 @@ class ObjectResource(ContentNegotiatedMethodView):
             current_app.logger.warning(
                 'File checksum mismatch detected.', extra=logger_data)
 
-        file_downloaded.send(current_app._get_current_object(), obj=obj)
+        file_downloaded.send(obj)
         return obj.send_file(restricted=restricted,
                              as_attachment=as_attachment)
 
