@@ -25,10 +25,10 @@ def test_signals(app, client, headers, bucket, permissions):
 
     calls = []
 
-    def upload_listener(sender, obj=None):
+    def upload_listener(obj):
         calls.append("file-uploaded")
 
-    def delete_listener(sender, obj=None):
+    def delete_listener(obj):
         calls.append("file-deleted")
 
     file_uploaded.connect(upload_listener, weak=False)
